@@ -1,4 +1,5 @@
 import traceback
+import requests
 from inspect import signature
 from types import FunctionType
 from concurrent.futures import ThreadPoolExecutor
@@ -6,7 +7,7 @@ from urllib.parse import urlparse, urlencode
 from typing import Union, Callable, List
 from selenium.webdriver.chrome.options import Options
 from .utils.logger import debug, info, warn, error
-from .utils.url import get_query_params, get_domain
+from .utils.url import get_query_params, get_domain, get_url_no_query_params
 from .utils.chrome_driver import build_driver, get_websocket_debugger_url
 from .utils.user_agent import get_random_user_agent
 from .query import Query, QueryOptions
@@ -14,7 +15,7 @@ from .utils.constants import JOBS_SEARCH_URL
 from .strategies import Strategy, AnonymousStrategy, AuthenticatedStrategy
 from .config import Config
 from .events import Events
-from .chrome_cdp import CDP, CDPRequest, CDPResponse
+from .chrome_cdp import CDP, CDPRequest, CDPResponse, CDPCookie
 from .exceptions import CallbackException, InvalidCookieException
 
 
@@ -35,6 +36,7 @@ class LinkedinScraper:
             chrome_executable_path = None,
             chrome_options: Options = None,
             headless: bool = True,
+            proxies: List[str] = None,
             max_workers: int = 2,
             slow_mo: float = 0.4):
 
@@ -56,6 +58,8 @@ class LinkedinScraper:
         self.chrome_options = chrome_options
         self.headless = headless
         self.slow_mo = slow_mo
+
+        self._proxies = proxies if proxies else []
         self._pool = ThreadPoolExecutor(max_workers=max_workers)
         self._strategy: Strategy
         self._emitter = {
@@ -68,6 +72,9 @@ class LinkedinScraper:
         if Config.LI_AT_COOKIE:
             info(f'Using strategy {AuthenticatedStrategy.__name__}')
             self._strategy = AuthenticatedStrategy(self)
+
+            if proxies:
+                warn(f'Proxy mode is currently not supported in {AuthenticatedStrategy.__name__}')
         else:
             info(f'Using strategy {AnonymousStrategy.__name__}')
             self._strategy = AnonymousStrategy(self)
@@ -153,7 +160,7 @@ class LinkedinScraper:
 
         tag = f'[{query.query}]'
         driver = None
-        devtools = None
+        cdp = None
 
         info('Starting new query', str(query))
 
@@ -170,7 +177,9 @@ class LinkedinScraper:
                 )
 
                 websocket_debugger_url = get_websocket_debugger_url(driver)
-                devtools = CDP(websocket_debugger_url)
+                cdp = CDP(websocket_debugger_url)
+                session = requests.Session()
+                proxy_index = 0
 
                 def on_request(request: CDPRequest) -> None:
                     domain = get_domain(request.url)
@@ -196,7 +205,69 @@ class LinkedinScraper:
                         if request.resource_type.lower() in types_to_block:
                             return request.abort()
 
-                    request.resume()
+                    # TODO: rotating proxy mode, only "working" in anonymous mode
+                    if len(self._proxies) > 0 and not Config.LI_AT_COOKIE:
+                        # Do not proxy request with non http(s) scheme
+                        if 'http' not in urlparse(request.url).scheme.lower():
+                            return request.resume()
+
+                        # Always got 400 on proxying these requests, reason still unknown...
+                        if 'api/ingraphs' in request.url:
+                            return request.resume()
+
+                        nonlocal session
+                        nonlocal proxy_index
+
+                        # Rotate proxy
+                        proxy = self._proxies[proxy_index % len(self._proxies)]
+                        proxy_index += 1
+
+                        # Try proxying the request
+                        debug(f'Proxying request to {proxy}', request.url, request.method)
+                        try:
+                            response = session.request(
+                                url=request.url,
+                                method=request.method,
+                                headers=request.headers,
+                                data=request.post_data,
+                                cookies=session.cookies,
+                                verify=False,
+                                proxies={
+                                    'http': proxy,
+                                    'https': proxy,
+                                },
+                            )
+                        # Resume request in case of a proxy error
+                        except requests.exceptions.ProxyError as e:
+                            warn(e)
+                            return request.resume()
+
+                        cdp_cookies = []
+
+                        for cookie in session.cookies:
+                            cdp_cookies.append(CDPCookie(
+                                name=cookie.name,
+                                value=cookie.value,
+                                domain=cookie.domain,
+                                secure=cookie.secure,
+                                expires=cookie.expires,
+                            ))
+
+                        # Set cookies from request session to browser
+                        cdp.set_cookies(cdp_cookies)
+
+                        try:
+                            return request.fulfill(
+                                code=response.status_code,
+                                headers=response.headers,
+                                body=response.content,
+                            )
+                        except Exception as e:
+                            print(e)
+                            return request.resume()
+                    # Non-proxy mode
+                    else:
+                        return request.resume()
 
                 def on_response(response: CDPResponse) -> None:
                     if response.status == 429:
@@ -206,24 +277,24 @@ class LinkedinScraper:
                         warn(tag, 'Error in response', str(response))
 
                 # Add request/response listeners
-                devtools.on('request', on_request)
-                devtools.on('response', on_response)
+                cdp.on('request', on_request)
+                cdp.on('response', on_response)
 
                 # Start devtools
-                devtools.start()
+                cdp.start()
 
                 # Enable Content Security Policy bypass: needed for pagination to work properly in anonymous mode
-                devtools.set_bypass_csp(True)
+                cdp.set_bypass_csp(True)
 
                 # Set random user agent
-                devtools.set_user_agent(get_random_user_agent())
+                cdp.set_user_agent(get_random_user_agent())
 
                 # Run strategy
                 self._strategy.run(driver, search_url, query, location)
 
                 try:
                     debug(tag, 'Stopping Chrome DevTools')
-                    devtools.stop()
+                    cdp.stop()
                 except:
                     pass
 
@@ -244,7 +315,7 @@ class LinkedinScraper:
         finally:
             try:
                 debug(tag, 'Stopping Chrome DevTools')
-                devtools.stop()
+                cdp.stop()
             except:
                 pass
 
@@ -361,3 +432,38 @@ class LinkedinScraper:
             raise ValueError(f'Event must be an instance of enum class Events')
 
         self._emitter[event] = []
+
+    def get_proxies(self):
+        """
+        Get proxies
+        :return: List[str]
+        """
+
+        return self._proxies
+
+    def set_proxies(self, proxies: List[str]):
+        """
+        Set proxies
+        :param proxies:
+        :return: None
+        """
+
+        self._proxies = proxies
+
+    def add_proxy(self, proxy: str):
+        """
+        Add a proxy
+        :param proxy:
+        :return: None
+        """
+
+        self._proxies.append(proxy)
+
+    def remove_proxy(self, proxy: str):
+        """
+        Remove a proxy
+        :param proxy:
+        :return: None
+        """
+
+        self._proxies = list(filter(lambda e: e != proxy, self._proxies))
