@@ -1,6 +1,7 @@
 import urllib3
 import json
 from selenium import webdriver
+from selenium.webdriver.common.proxy import Proxy, ProxyType
 from selenium.webdriver.chrome.options import Options
 from linkedin_jobs_scraper.utils.logger import debug
 
@@ -27,15 +28,14 @@ def get_default_driver_options(width=1472, height=828, headless=True) -> Options
     chrome_options.add_argument("--disable-dev-shm-usage"),
     chrome_options.add_argument("--disable-gpu"),
     chrome_options.add_argument("--disable-accelerated-2d-canvas"),
-    chrome_options.add_argument("--disable-setuid-sandbox"),
-    chrome_options.add_argument("--disable-dev-shm-usage"),
-    chrome_options.add_argument("--proxy-server='direct://"),
-    chrome_options.add_argument("--proxy-bypass-list=*"),
+    # chrome_options.add_argument("--proxy-server='direct://"),
+    # chrome_options.add_argument("--proxy-bypass-list=*"),
     chrome_options.add_argument("--allow-running-insecure-content"),
     chrome_options.add_argument("--disable-web-security"),
     chrome_options.add_argument("--disable-client-side-phishing-detection"),
     chrome_options.add_argument("--disable-notifications"),
     chrome_options.add_argument("--mute-audio"),
+    chrome_options.add_argument("--ignore-certificate-errors"),
 
     # Disable downloads
     chrome_options.add_experimental_option(
@@ -51,6 +51,24 @@ def get_default_driver_options(width=1472, height=828, headless=True) -> Options
     return chrome_options
 
 
+def get_driver_proxy_capabilities(proxy: str):
+    """
+    Use a single proxy directly from the browser
+    :param proxy:
+    :return:
+    """
+
+    proxy = Proxy()
+    proxy.proxy_type = ProxyType.MANUAL
+    proxy.http_proxy = proxy
+    proxy.ssl_proxy = proxy
+    proxy.ftp_proxy = proxy
+    proxy.auto_detect = False
+    capabilities = webdriver.DesiredCapabilities.CHROME.copy()
+    proxy.add_to_capabilities(capabilities)
+    return capabilities
+
+
 def build_driver(executable_path: str = None, options: Options = None, headless=True, timeout=20) -> webdriver:
     """
     Build Chrome driver instance
@@ -67,6 +85,7 @@ def build_driver(executable_path: str = None, options: Options = None, headless=
         kwargs['executable_path'] = executable_path
 
     kwargs['options'] = options if options is not None else get_default_driver_options(headless=headless)
+    # kwargs['desired_capabilities'] = get_driver_proxy_capabilities('http://localhost:8888')
 
     driver = webdriver.Chrome(**kwargs)
     driver.set_page_load_timeout(timeout)
