@@ -12,6 +12,18 @@ def get_query_params(url: str) -> dict:
     return dict(parse_qsl(parsed.query))
 
 
+def get_url_no_query_params(url: str) -> str:
+    """
+    Returns url without query parameters
+    :param url:
+    :return:
+    """
+
+    parsed = urlparse(url)
+    parsed = parsed._replace(query='')
+    return parsed.geturl()
+
+
 def override_query_params(url: str, override_params: dict) -> str:
     """
     Override url query parameters
